@@ -50,8 +50,7 @@ use warnings FATAL => "all";
 use Mouse;
 use AnyEvent;
 
-
-our $VERSION = 0.3.2;
+our $VERSION = 0.3.3;
 
 =for comment
 
@@ -310,6 +309,9 @@ sub found {
     for my $watcher (@ready_watchers)
     {
         $self->_dispatch($watcher);
+
+        # Break out of the loop if hangup was invoked during dispatching.
+        last if $self->_hangup;
     }
 }
 
